# Copyright 1999-2000 Gentoo Technologies, Inc.
# Distributed under the terms of the GNU General Public License, v2 or later
# Author David Snopek

S=${WORKDIR}/${P}
DESCRIPTION="LTSP - Linux Terminal Server Project"
SF_MIRROR="telia.dl.sourceforge.net/sourceforge"
SRC_URI="http://$SF_MIRROR/ltsp/ltsp_core-3.0.0-i386.tgz
		 http://$SF_MIRROR/ltsp/ltsp_kernel-3.0.1-i386.tgz
		 http://$SF_MIRROR/ltsp/ltsp_x_core-3.0.1-i386.tgz
		 http://$SF_MIRROR/ltsp/ltsp_x_fonts-3.0.0-i386.tgz
		 http://$SF_MIRROR/ltsp/ltsp_x336_3dlabs-3.0.0-i386.tgz
		 http://$SF_MIRROR/ltsp/ltsp_x336_8514-3.0.0-i386.tgz
		 http://$SF_MIRROR/ltsp/ltsp_x336_agx-3.0.0-i386.tgz
		 http://$SF_MIRROR/ltsp/ltsp_x336_fbdev-3.0.0-i386.tgz
		 http://$SF_MIRROR/ltsp/ltsp_x336_i128-3.0.0-i386.tgz
		 http://$SF_MIRROR/ltsp/ltsp_x336_mach32-3.0.0-i386.tgz
		 http://$SF_MIRROR/ltsp/ltsp_x336_mach64-3.0.0-i386.tgz
		 http://$SF_MIRROR/ltsp/ltsp_x336_mach8-3.0.0-i386.tgz
		 http://$SF_MIRROR/ltsp/ltsp_x336_mono-3.0.0-i386.tgz
		 http://$SF_MIRROR/ltsp/ltsp_x336_p9000-3.0.0-i386.tgz
		 http://$SF_MIRROR/ltsp/ltsp_x336_s3-3.0.0-i386.tgz
		 http://$SF_MIRROR/ltsp/ltsp_x336_s3v-3.0.0-i386.tgz
		 http://$SF_MIRROR/ltsp/ltsp_x336_svga-3.0.0-i386.tgz
		 http://$SF_MIRROR/ltsp/ltsp_x336_vga16-3.0.0-i386.tgz
		 http://$SF_MIRROR/ltsp/ltsp_x336_w32-3.0.0-i386.tgz"
HOMEPAGE="http://www.ltsp.org/"

RDEPEND="gnome? (gnome-base/gdm)
		 kde? (kde-base/kdebase)
		 x11-base/xfree86
		 app-admin/tftp-hpa
		 sys-apps/xinetd
		 net-misc/dhcp
		 net-fs/nfs-utils"

DEPEND="${RDEPEND}"

readlink() {
	echo ls -ld $1 | sed "s/^.*-> //"
}

ltsp_strip_config() {
	local SOURCE="/"$1
	local TARGET=${D}/$SOURCE
	sed -e "/## LTS-begin ##/,/## LTS-end ##/d" < ${SOURCE} >> ${TARGET}
}

ltsp_copy_config() {
	local SOURCE="/"$1
	local TARGET=${D}/$SOURCE
	if test -f $SOURCE ; then
		cp $SOURCE $TARGET
	else
		echo "!!! No config file named $SOURCE"
		return 1
	fi
}

modify_exports()
{
	echo ">>> Modifying /etc/exports ..."

	# get the file
	ltsp_strip_config /etc/exports
	
	# insert new data
	cat >> ${D}/etc/exports <<EOF

## LTS-begin ##

#
# The lines between the 'LTS-begin' and the 'LTS-end' were added
# on: `date` by the ltsp installation script.
# For more information, visit the ltsp homepage
# at http://www.ltsp.org
#

/opt/ltsp/i386                  192.168.0.0/255.255.255.0(ro,no_root_squash)
/var/opt/ltsp/swapfiles         192.168.0.0/255.255.255.0(rw,no_root_squash)

#
# The following entries need to be uncommented if you want
# Local App support in ltsp
#
#/home                  192.168.0.0/255.255.255.0(rw,no_root_squash)

## LTS-end ##
EOF

}

modify_xdm_xdm_config()
{
	local file=/etc/X11/xdm/xdm-config

	if [ -f $file ] ; then
		echo ">>> Modifying $file ..."

		# get file
		ltsp_strip_config $file

		# make temp file
		mv ${D}$file ${D}$file.temp

		cat >> ${D}$file.temp <<EOF

## LTS-begin ##

#
# The lines between the 'LTS-begin' and the 'LTS-end' were added
# on: Mon Jan 21 21:40:50 CST 2002 by the ltsp installation script.
# For more information, visit the ltsp homepage
# at http://www.ltsp.org
#

DisplayManager.*.setup:     /etc/X11/xdm/Xsetup_workstation

## LTS-end ##
EOF

		# comment out display port line
		sed -e "s/^DisplayManager\.requestPort/\# DisplayManager.requestPort/" \
			< ${D}$file.temp >> ${D}$file

		# remove temp file
		rm -f ${D}$file.temp
	else
		echo "!!! $file not installed on system"
	fi
}

modify_xdm_Xservers()
{
	local file=/etc/X11/xdm/Xservers

	if [ -f $file ] ; then
		echo ">>> Modifying $file ..."

		# get file
		ltsp_strip_config $file

		# TODO: put this comment in a more sensical place!!
		cat >> ${D}$file <<EOF

## LTS-begin ##

# Comment the above line in order to disable xdm for the local machine!

## LTS-end ##
EOF
	else
		echo "!!! $file not installed on system"
	fi
}

modify_xdm_kdmrc() 
{
	local file=/etc/X11/xdm/kdmrc

	if [ -f $file ] ; then
		echo ">>> Modifying $file ..."

		# get file
		ltsp_strip_config $file

		# make temp file
		mv ${D}$file ${D}$file.temp
	
		# run custom perl script to modify the kdmrc
		${FILESDIR}/kdmrc.pl < ${D}/$file.temp >> ${D}/$file

		# remove temp file
		rm -f ${D}$file.temp
	else
		echo "!!! $file not installed on system"
	fi

}

modify_gdm_gdm_conf()
{
	local file=/etc/X11/gdm/gdm.conf

	if [ -f $file ] ; then
		echo ">>> Modifying $file ..."

		# get file
		ltsp_strip_config $file

		# make temp file
		mv ${D}$file ${D}$file.temp
	
		# run custom perl script to modify the gdm.conf
		${FILESDIR}/gdm.conf.pl < ${D}/$file.temp >> ${D}/$file

		# remove temp file
		rm -f ${D}$file.temp
	else
		echo "!!! $file not installed on system"
	fi
}

src_install() {
	local XSERVERS="3dlabs 8514 agx fbdev i128 mach32 mach64 mach8 mono p9000 \
					s3 s3v svga w32"

	echo ">>> Installing root LTSP directory ..."
	cd ${WORKDIR}/ltsp_core
	${FILESDIR}/install.sh i386 ${D}/opt/ltsp/
	dodoc INSTALL README ${FILESDIR}/INSTALL.Gentoo

	echo ">>> Installing the X core ..."
	cd ${WORKDIR}/ltsp_x_core
	${FILESDIR}/install.sh i386 ${D}/opt/ltsp/

	echo ">>> Installing the X fonts ..."
	cd ${WORKDIR}/ltsp_x_fonts
	${FILESDIR}/install.sh i386 ${D}/opt/ltsp/

	echo ">>> Installing the LTSP kernel ..."
	cd ${WORKDIR}/ltsp_kernel
	${FILESDIR}/install.sh i386 ${D}/opt/ltsp/
	dodir /tftpboot/lts
	cp vmlinuz* ${D}/tftpboot/lts

	echo ">>> Installing the X Servers ..."
	for d in $XSERVERS ; do
		cd ${WORKDIR}/ltsp_x336_$d
		${FILESDIR}/install.sh i386 ${D}/opt/ltsp/
	done

	# make config dirs
	dodir /etc
	dodir /etc/X11/xdm
	dodir /etc/X11/gdm
	dodir /etc/init.d
	dodir /etc/dhcp
	dodir /etc/xinetd.d

	echo ">>> Copy the ltsp.conf file ..."
	cp ${FILESDIR}/ltsp.conf ${D}/etc/

	echo ">>> Copying xdm files ..."
	cp ${FILESDIR}/Xsetup_workstation ${D}/etc/X11/xdm/
	cp ${FILESDIR}/ltsp.gif ${D}/etc/X11/xdm/
	cp ${FILESDIR}/Xaccess ${D}/etc/X11/xdm/

	echo ">>> Copying dhcp files ..."
	cp ${FILESDIR}/dhcpd.conf ${D}/etc/dhcp/
	cp ${FILESDIR}/dhcp ${D}/etc/init.d/

	echo ">>> Copying xinetd files ..."
	cp ${FILESDIR}/tftp ${D}/etc/xinetd.d/

	# modify config files
	modify_exports
	modify_xdm_xdm_config
	modify_xdm_Xservers
	modify_xdm_kdmrc
	modify_gdm_gdm_conf

	# gdm requires a custom config
	if [ -n `use gnome` ]; then
		ltsp_copy_config /etc/X11/gdm/Default

		if test -f ${D}/etc/X11/gdm/Default -o -L ${D}/etc/X11/gdm/Default; then
			mv ${D}/etc/X11/gdm/Default ${D}/etc/X11/gdm/\:0
		fi
		
		ln -s /etc/X11/xdm/Xsetup_workstation ${D}/etc/X11/gdm/Default
	fi

	# ensure that these directories get copied even though they are empty
	for empty_dir in dev oldroot proc root tmp ; do
		echo -n > ${D}/opt/ltsp/i386/${empty_dir}/.keep
	done
}


